/* ************************************************************************** */
/*    NAME: aml.sas                                                           */
/*   TITLE: Anti-Money Laundering Process                                     */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/* ************************************************************************** */

/* ********************************************************************** */
/*  Copyright (c) 2012-2013 by SAS Institute Inc., Cary, NC 27513 USA     */
/*  ---All Rights Reserved.                                               */
/* ********************************************************************** */

/* ************************************************************************** */
/*                                                                            */
/*       Host and Site specific customizations may be REQUIRED                */
/*                                                                            */
/* ************************************************************************** */

%macro aml ;

   /* Get the runasofdate from the FSK_JOB_CALENDAR table in the KC */
   %aml_getrundate;
   %put NOTE: AML: runasofdate=&runasofdate;

   /* Prep Processing */
   %aml_section_header(Section=AML_PREP);
      %aml_prep;
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
      %end;
   %aml_section_footer(Section=AML_PREP);

   /*-----------------------------
    * Set the AML start datetime.
    *-----------------------------*/
   %aml_start_datetime_init;
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
   %end;

   /* Alert Generation */
   %aml_section_header(Section=AML_AGP);
      %aml_agp;
      %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
         %goto MACRO_END;
      %end;
   %aml_section_footer(Section=AML_AGP);

   /* Update the FSK_JOB_CALENDAR table to the next run date */
      %update_calendar;

   /* Batch Reports */
   %aml_section_header(Section=AML_BATCH_REPORTS);
      %batch_reports ;
   %aml_section_footer(Section=AML_BATCH_REPORTS);

   /*-------------------------------
    * Clear the AML start datetime.
    *-------------------------------*/
   %aml_start_datetime_clear;
   %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %goto MACRO_END;
   %end;

/* RDBMS Maintenance */
   %aml_section_header(Section=ANALYZE_KC);
      %aml_analyze_kc;
   %aml_section_footer(Section=ANALYZE_KC);


   %MACRO_END:

      %if &trans_rc eq 3 or &trans_rc ge 5 %then
         %execute_macro(amlerror);
      %else %do;
         %execute_macro(amlsuccess);
      %end;

%mend;
