/******************************************************************************/
/*                  S A S   S A M P L E   L I B R A R Y                       */
/*                                                                            */
/*    NAME: aml_run_generated_headers.sas                                     */
/*   TITLE: Alert Generation Process                                          */
/* PRODUCT: SAS Anti-Money Laundering                                         */
/*  SYSTEM: UNIX/WINDOWS                                                      */
/******************************************************************************/

/* ************************************************************************ */
/*  Copyright (c) 2012-2013 by SAS Institute Inc., Cary, NC 27513 USA       */
/*  ---All Rights Reserved.                                                 */
/* ************************************************************************ */

%macro aml_run_generated_headers(inLib=STG_ALER,
                                 inDS=generated_headers,
                                 exclude_header=,
                                 seg_kc_lib=seg_kc);

  /*------------
   * Set Module
   *------------*/
  %local _amlmodule_;
  %let _amlmodule_=AML_RUN_GENERATED_HEADERS;

  /* Set start time for jobstats */
  %aml_section_header(section=&_amlmodule_);

  %let _amlmsg_=NOTE: AML: Running generated headers.;
  %put_aml_error;
  
  proc sort data=&inLib..&inDS;
    by header_id;
   run;

  %aml_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _amlmsg_=ERROR: AML: Unable to sort &inLib..&inDS;
     %put_aml_error;
     %goto MACRO_FINAL_END;
  %end;

  proc sort data=&seg_kc_lib..fsk_header(keep=header_id header_name)
             out=generated_header_names;
    by header_id;
   run;

  %aml_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _amlmsg_=ERROR: AML: Unable to sort &seg_kc_lib..fsk_header;
     %put_aml_error;
     %goto MACRO_FINAL_END;
  %end;

  data generated_header_names;
    merge &inLib..&inDS(in=a) generated_header_names(in=b);
    by header_id;
    if a and b;
    %if &exclude_header ne  %then %do;
     if not indexw("&exclude_header", header_name);
    %end;
   run;

  %aml_rcset(&syserr);
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
     %let _amlmsg_=ERROR: AML: Unable to merge &inLib..&inDS and &seg_kc_lib..fsk_header;
     %put_aml_error;
     %goto MACRO_FINAL_END;
  %end;

  %let dsidrungenheader = %sysfunc(open(generated_header_names));
  %if &dsidrungenheader ne 0 %then %do;
    %syscall set(dsidrungenheader);
    %let numgenheaders = %sysfunc(attrn(&dsidrungenheader, nlobs));
    %if &numgenheaders gt 0 %then %do;
      %do rowgenheader = 1 %to &numgenheaders;
        %let rcfetchgenheader = %sysfunc(fetchobs(&dsidrungenheader,&rowgenheader));
        %if &rcfetchgenheader = 0 %then %do;

          %let stripped_header_name = &header_name;
          %aml_section_header(Section=%upcase(&stripped_header_name));
            %include "!AMLROOT/scenario/codegen/&stripped_header_name..sas";
            %aml_rcset(&syserr)
            %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
               %let _AMLMODULE_=&stripped_header_name;
               %let _amlmsg_=ERROR: AML: &stripped_header_name..sas failed check log.;
               %put_aml_error;
               %goto MACRO_END;
            %end;
          %aml_section_footer(Section=%upcase(&stripped_header_name));

        %end;
      %end;
    %end;
  %end;
  %else %goto MACRO_FINAL_END;

  %MACRO_END:
  %let dsidrungenheader = %sysfunc(close(&dsidrungenheader));

  %MACRO_FINAL_END:

   /* Set end time and calculate elapsed processing time for jobstats */
   %aml_section_footer(section=%upcase(&_amlmodule_));

%mend aml_run_generated_headers;
