
/****************************************************************************/
/*          S A S   S A M P L E   L I B R A R Y                             */
/*                                                                          */
/*     NAME: batch_reports.sas                                              */
/* FUNCTION: Executes batch reports                                         */
/*  PRODUCT: SAS Anti-Money Laundering                                      */
/*   SYSTEM: WINDOWS, UNIX                                                  */
/****************************************************************************/

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*   CREATE FORMATS THAT ARE USED IN THE REPORTS
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
%macro batch_reports / DES='AML51HF1 - Batch Reports';

  /*--------------------------------------------------------
   * Make sure the AML start datetime has been set.
   * Assign its value to macro variable aml_start_datetime.
   *--------------------------------------------------------*/
  %aml_start_datetime_read;
  %if &trans_rc eq 3 or &trans_rc ge 5 %then %do;
    %goto MACRO_END;
  %end;


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*   Global date and version numbers (optional) for use in option footnotes
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
   %global  aml_footnote_date aml_footnote_version;
   /* Set Module Name */
   %local _AMLMODULE_;
   %let _AMLMODULE_=BATCH_REPORTS;
   %let _amlmsg_ = NOTE: Start of Batch Reports;
   %put_aml_error;
   %let aml_footnote_version=Version = &_AMLMODULEVER_;

   data _null_;
      call symput('aml_footnote_date',put(datepart(&aml_start_datetime),worddate20.));
   run;
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*   Create Special Styles - AMLWEB - mod of the default outputstyle=SASWEB
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
    %update_report_output_styles ;

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*   GLOBAL VALUES FOR ODS OUTPUT PARAMETERS
/*   IMPORTANT: The following are global variables used by all reports. Any
/*   changes to these variables affects all reports.
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
    %global  outputBody  outputDevice outputStyle;
    %let outputBody=body.htm ;   /* Main link to report in output directory */
    %let outputDevice=javaimg ;   /* How report is rendered                  */

/* ------------------------------------------------------------------------ */
/*   Status of All Alerts
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/duration_of_alerts;
    %let display_limit=1000;
    %alert_age_report ;

/* ------------------------------------------------------------------------ */
/*   Monthly Trend Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/alerts_by_month;
    %monthly_trend_report ;

/* ------------------------------------------------------------------------ */
/*   Weekly Trend Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/alerts_by_week;
    %let num_weeks = 33;
    %weekly_trend_report ;

/* ------------------------------------------------------------------------ */
/*   Distribution of Active Alerts
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/dist_active_alerts;
    %dist_active_alerts_report ;

/* ------------------------------------------------------------------------ */
/*   Distribution of Scenarios
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/scenario_distribution;
    %scenario_distribution_report ;

/* ------------------------------------------------------------------------ */
/*   Active Alert Ownership
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------ ----------- */

    %let outputDirectory=&AMLROOT./reports/alert_ownership;
    %owner_report ;

/* ------------------------------------------------------------------------ */
/*  HEADERS --------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* ------------------------------------------------------------------------ */
/*   List of Active Headers and Associted Header Elements
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/header_elements_report;
    %header_elements_report ;

/* ------------------------------------------------------------------------ */
/*  SCENARIOS ------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/*   Scenario List Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let outputDirectory=&AMLROOT./reports/scenario_status_report;
    %scenario_list_report ;

/* ------------------------------------------------------------------------ */
/*   Scenario Change Audit report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let  outputDirectory=&AMLROOT./reports/scenario_audit_report;
    %let  number_days=999;
    %scenario_audit_report ;

/* ------------------------------------------------------------------------ */
/*   Job Statistics report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

    %let  outputDirectory=&AMLROOT./reports/summarize_job_stats_report;
    %summarize_job_stats ;
/* ------------------------------------------------------------------------ */
/*  BAYES ANALYSIS -------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* ------------------------------------------------------------------------ */
/*   Bayes Alert Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

   %let outputDirectory=&AMLROOT./reports/bayes_alert_report;
   %bayes_alert_report (ML=%str('Reason Code = MLI') ,
                        TF = %str('Reason Code=OTH') ,
                        begin_date=%str('01JAN2003') ,
                        end_date=%str('31MAY2007')) ;

/* ------------------------------------------------------------------------ */
/*   Bayes SAR Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */
   %let outputDirectory=&AMLROOT./reports/bayes_sar_report;
   %bayes_sar_report (ML=%str('MON') ,
                        TF = %str('TER') ,
                        begin_date=%str('01JAN2003') ,
                        end_date=%str('31MAY2007')) ;

/* ------------------------------------------------------------------------ */
/*   Risk Classifier and Lists Reports                                      */
/* ------------------------------------------------------------------------ */
/* ------------------------------------------------------------------------ */
/*    Risk Classifiers by Risk Classifier Category Spreadsheet
/*    See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

      %let outputDirectory=&AMLROOT./reports/risk_classifier_report ;
      %risk_classifier_report ;

/* ------------------------------------------------------------------------ */
/*    Lists by List Category Spreadsheet
/*    See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

      %let outputDirectory=&AMLROOT./reports/lists_report ;
      %list_report ;

/* ------------------------------------------------------------------------ */
/*  Administrative Reports------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* ------------------------------------------------------------------------ */
/*    Users
/*    List of Users by Groups
/* ------------------------------------------------------------------------ */

      %let outputDirectory=&AMLROOT./reports/users_by_group_report;
      %users_by_group_report ;

/* ------------------------------------------------------------------------ */
/*   LOV Table Report
/*   See documentation for additional optional reporting parameters
/* ------------------------------------------------------------------------ */

      %let outputDirectory=&AMLROOT./reports/lov_table_report;
      %lov_report ;

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/*   END OF REPORTS
/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

  %MACRO_END:
  
%mend batch_reports;
